@@ -204,7 +204,8 @@ class Calendar
      *
      * @access protected
      */
-    function Calendar($y = 2000, $m = 1, $d = 1, $h = 0, $i = 0, $s = 0)
+//    function Calendar($y = 2000, $m = 1, $d = 1, $h = 0, $i = 0, $s = 0)
+	function __construct($y = 2000, $m = 1, $d = 1, $h = 0, $i = 0, $s = 0)
     {
         static $cE = null;
         if (!isset($cE)) {
@@ -404,13 +405,24 @@ class Calendar
      */
     function fetch()
     {
-        $child = each($this->children);
+/*        $child = each($this->children);
         if ($child) {
             return $child['value'];
         } else {
             reset($this->children);
             return false;
         }
+		*/
+		// PHP7.2非奨励のeach()を置き換え
+		$key = key($this->children);
+		if ($key){
+			$value = $this->children[$key];
+			next($this->children);
+			return $value;
+		} else {
+			reset($this->children);
+			return false;
+		}
     }
 
     /**
