@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2017 Magic3 Project.
+ * @copyright  Copyright 2006-2018 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -41,6 +41,7 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 	const CF_SMARTPHONE_AUTO_REDIRECT = 'smartphone_auto_redirect';			// スマートフォンの自動遷移
 	const CF_SITE_SMARTPHONE_URL = 'site_smartphone_url';		// スマートフォン用サイトURL
 	const CF_SITE_MOBILE_URL = 'site_mobile_url';		// 携帯用サイトURL
+	const CF_SITE_OPERATION_MODE = 'site_operation_mode';			// サイト運用モード
 	const CF_ACCESS_IN_INTRANET = 'access_in_intranet';		// イントラネット運用
 	const CF_MULTI_DOMAIN = 'multi_domain';		// マルチドメイン運用
 	const CF_SITE_ACCESS_EXCEPTION_IP = 'site_access_exception_ip';		// アクセス制御、例外とするIP
@@ -347,6 +348,12 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			$this->db->updateSystemConfig(self::CF_SITE_IN_PUBLIC, 1);
 		} else if ($act == 'siteclose'){		// サイト運用停止のとき
 			$this->db->updateSystemConfig(self::CF_SITE_IN_PUBLIC, 0);
+		} else if ($act == 'site_operation_mode_on'){			// サイト運用モード変更
+			// システム制御マネージャーの値を更新
+			$this->gSystem->updateSystemConfig(self::CF_SITE_OPERATION_MODE, 1);
+		} else if ($act == 'site_operation_mode_off'){			// サイト運用モード変更
+			// システム制御マネージャーの値を更新
+			$this->gSystem->updateSystemConfig(self::CF_SITE_OPERATION_MODE, 0);
 		} else if ($act == 'clearcache'){		// キャッシュクリアのとき
 			$ret = $this->gCache->clearAllCache();
 			if ($ret){
@@ -420,16 +427,13 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		$this->tmpl->addVar("show_site_mobile_open", "mobile_encode", $this->gEnv->getMobileEncoding());
 		
 		// サイト運用状況を設定
-		if ($this->gSystem->siteInPublic(true/*再取得*/)){		// 運用中のとき
-			$this->tmpl->addVar("_widget", "site_open", '<b><font color="green">公開中</font></b>');
-			$this->tmpl->addVar("_widget", "site_open_status", '0');
-			$this->tmpl->addVar("_widget", "site_open_label", '公開停止');
-		} else {
-			$this->tmpl->addVar("_widget", "site_open", '非公開');
-			$this->tmpl->addVar("_widget", "site_open_status", '1');
-			$this->tmpl->addVar("_widget", "site_open_label", '公開開始');
-		}
+		$checked = '';
+		if ($this->gSystem->siteInPublic(true/*再取得*/)) $checked = 'checked';		// 運用中のとき
+		$this->tmpl->addVar("_widget", "site_status_checked", $checked);
 		$this->tmpl->addVar("_widget", "except_ip", $this->db->getSystemConfig(self::CF_SITE_ACCESS_EXCEPTION_IP));
+		$checked = '';
+		if ($this->db->getSystemConfig(self::CF_SITE_OPERATION_MODE) == '1') $checked = 'checked';		// サイト運用モードのとき
+		$this->tmpl->addVar("_widget", "site_operation_mode_checked", $checked);
 		
 		// 項目の表示制御
 		$isActiveSite = $this->gSystem->getSiteActiveStatus(0);		// PC用サイト
